﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Common.Ajax.Extension
{
    internal static class TypeExtension
    {
        /// <summary>
        /// 判断是否是受支持的基本类型
        /// </summary>
        /// <param name="type"></param>
        /// <returns></returns>
        public static bool IsValueType(this Type type)
        {
            return type.IsPrimitive || type == typeof(string) || type.IsEnum;
        }

        /// <summary>
        /// 获取实际类型。如果 type 为 int? 则返回 int
        /// </summary>
        /// <param name="type"></param>
        /// <returns></returns>
        public static Type GetRealType(this Type type)
        {
            if (type.IsGenericType)
            {
                return Nullable.GetUnderlyingType(type) ?? type;
            }
            return type;
        }

        /// <summary>
        /// 是否是浮点数类型
        /// 需要为浮点数类型赋值
        /// </summary>
        /// <param name="type"></param>
        /// <returns></returns>
        public static bool IsFloatType(this Type type)
        {
            return type == typeof(float) || type == typeof(double) || type == typeof(decimal);
        }
    }
}
