﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Common.Ajax
{
    /// <summary>
    /// ajax方法标记属性
    /// </summary>
    [AttributeUsage(AttributeTargets.Method, AllowMultiple = false, Inherited = false)]
    public class AjaxMethodAttribute : Attribute
    {
        public AjaxMethodAttribute()
        {           
        }

        private SessionState _sessionState = SessionState.None;
        private int _outputCache = 0;
        private int _serverCache = 0;
        private ContentType _contentType = ContentType.Plain;
        private bool _isUseAsync = false;

        /// <summary>
        /// session状态
        /// </summary>
        public SessionState SessionState 
        {
            get { return _sessionState; }
            set { _sessionState = value; }
        }

        /// <summary>
        /// 客户端缓存时间，以秒为单位。该标记只对get请求有效
        /// </summary>
        public int OutputCache 
        {
            get { return _outputCache; }
            set { _outputCache = value; }
        }

        /// <summary>
        /// 服务端缓存时间，以秒为单位
        /// </summary>
        public int ServerCache 
        {
            get { return _serverCache; }
            set { _serverCache = value; }
        }        

        /// <summary>
        /// 输出类型（默认为text/plain）
        /// </summary>
        public ContentType ContentType 
        {
            get { return _contentType; }
            set { _contentType = value; }
        }

        /// <summary>
        /// 使用启用异步处理
        /// </summary>
        public bool IsAsync 
        {
            get { return _isUseAsync; }
            set { _isUseAsync = value; }
        }
    }

    /// <summary>
    /// Session状态
    /// </summary>
    public enum SessionState
    {
        None,
        ReadOnly,
        ReadWrite        
    }

    /// <summary>
    /// 输出内容类型
    /// </summary>
    public enum ContentType
    {
        Plain,
        Html,
        XML,
        Javascript,
        JSON
    }
}
