﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Web;
using System.Collections;
using Common.Ajax.Service;
using Common.Ajax.Extension;
using System.Reflection;

namespace Common.Ajax.Utility
{
    internal static class ModelUtil
    {
        /// <summary>
        /// 缓存构造函数
        /// </summary>
        private static Hashtable constructorTable = Hashtable.Synchronized(new Hashtable());
 
        /// <summary>
        /// 根据名称从HttpRequest获取值
        /// </summary>
        /// <param name="request">HttpRequest</param>
        /// <param name="name">键名称</param>
        /// <param name="type">参数类型</param>
        /// <returns></returns>
        public static object GetValue(HttpRequest request, string name, Type type)
        {
            string[] values = null;
            if (string.Compare(request.RequestType, "POST", true) == 0)
            {
                values = request.Form.GetValues(name);
            }
            else
            {
                values = request.QueryString.GetValues(name);
            }
            if (values.IsNullOrEmpty())
            {
                return null;
            }
            string data = values.Length == 1 ? values[0] : string.Join(",", values);
            return Convert.ChangeType(data, type);
        }

        /// <summary>
        /// 创建实例对象
        /// </summary>
        /// <param name="type">实例类型</param>
        /// <returns></returns>
        public static object CreateModel(Type type)
        {
            if (type == null)
            {
                throw new ArgumentNullException("type");
            }
            Func<object> func = constructorTable[type.AssemblyQualifiedName] as Func<object>;
            if (func == null)
            {   
                func = ReflectionUtil.GetConstructorDelegate(type);
                constructorTable[type.AssemblyQualifiedName] = func;
            }
            if (func != null)
            {
                return func();
            }
            return null;
        }

        /// <summary>
        /// 填充模型
        /// </summary>
        /// <param name="request">HttpRequest</param>
        /// <param name="name">键名称</param>
        /// <param name="prefix">参数类型</param>
        /// <parparam name="model">实例对象</parparam>
        public static void FillModelByRequest(HttpRequest request, string name, Type type, object model)
        {
            if (model == null)
            {
                return;
            }
            IEnumerable<DataMember> members = DataMemberManager.GetDataMember(type);
            if (members.IsNullOrEmpty())
            {
                return;
            }
            object value = null;
            foreach (DataMember member in members)
            {
                value = GetValue(request, string.Format("{0}.{1}", name, member.Name), member.MemberType);
                value = value ?? GetValue(request, member.Name, member.MemberType);
                member.SetValue(model, value);
            }
        }
    }
}
